summaryrefslogtreecommitdiffstats
path: root/src/kvilib/core/kvi_pointerhashtable.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvilib/core/kvi_pointerhashtable.h')
-rw-r--r--src/kvilib/core/kvi_pointerhashtable.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/kvilib/core/kvi_pointerhashtable.h b/src/kvilib/core/kvi_pointerhashtable.h
index dceceeda..1c2bcab3 100644
--- a/src/kvilib/core/kvi_pointerhashtable.h
+++ b/src/kvilib/core/kvi_pointerhashtable.h
@@ -349,7 +349,7 @@ public:
/// Places the hash table iterator at the position
/// of the item found.
///
- T * tqfind(const Key & hKey)
+ T * find(const Key & hKey)
{
m_uIteratorIdx = kvi_hash_hash(hKey,m_bCaseSensitive) % m_uSize;
if(!m_pDataArray[m_uIteratorIdx])return 0;
@@ -364,11 +364,11 @@ public:
/// Returns the item associated to the key hKey
/// or NULL if no such item exists in the hash table.
/// Places the hash table iterator at the position
/// of the item found. This is an alias to tqfind().
///
T * operator[](const Key & hKey)
{
- return tqfind(hKey);
+ return find(hKey);
}
///
@@ -427,7 +427,7 @@ public:
/// The hash table iterator is placed at the newly inserted item.
/// This is just an alias to insert() with a different name.
///
- void tqreplace(const Key & hKey,T * pData)
+ void replace(const Key & hKey,T * pData)
{
insert(hKey,pData);
}
@@ -522,7 +522,7 @@ public:
/// it's hash table entry, if found, and NULL otherwise.
/// The hash table iterator is placed at the item found.
///
- KviPointerHashTableEntry<Key,T> * tqfindRef(const T * pRef)
+ KviPointerHashTableEntry<Key,T> * findRef(const T * pRef)
{
for(m_uIteratorIdx = 0;m_uIteratorIdx<m_uSize;m_uIteratorIdx++)
{
@@ -540,7 +540,7 @@ public:
///
/// Returns the entry pointed by the hash table iterator.
/// This function must be preceeded by a call to firstEntry(), first()
- /// or tqfindRef().
+ /// or findRef().
///
KviPointerHashTableEntry<Key,T> * currentEntry()
{
@@ -568,7 +568,7 @@ public:
/// Places the hash table iterator at the next entry
/// and returns it.
/// This function must be preceeded by a call to firstEntry(), first()
- /// or tqfindRef().
+ /// or findRef().
///
KviPointerHashTableEntry<Key,T> * nextEntry()
{
@@ -596,7 +596,7 @@ public:
///
/// Returns the data value pointer pointed by the hash table iterator.
/// This function must be preceeded by a call to firstEntry(), first()
- /// or tqfindRef().
+ /// or findRef().
///
T * current()
{
@@ -613,7 +613,7 @@ public:
///
/// Returns the key pointed by the hash table iterator.
/// This function must be preceeded by a call to firstEntry(), first()
- /// or tqfindRef().
+ /// or findRef().
///
const Key & currentKey()
{
@@ -648,7 +648,7 @@ public:
/// Places the hash table iterator at the next entry
/// and returns the associated data value pointer.
/// This function must be preceeded by a call to firstEntry(), first()
- /// or tqfindRef().
+ /// or findRef().
///
T * next()
{
@@ -364,11 +364,11 @@ public:
/// or NULL if no such item exists in the hash table.
/// Places the hash table iterator at the position
- /// of the item found. This is an alias to tqfind().
+ /// of the item found. This is an alias to find().
///
T * operator[](const Key & hKey)